import { Grid } from "@mui/material";
import React, { memo, useMemo} from "react";
import ContentCopyIcon from '@mui/icons-material/ContentCopy';
import { getColorTaskByPriority } from "../../../../../helpers/CalendarHelpers";





const CalendarTask = ({ setCurrentTask, handleOpen, task, line, setCopyTask, width, left,top }) => {


  const color = useMemo(() => {
    return getColorTaskByPriority(task.priority)
  }, [task.priority])

  const styles = {
    boxSizing: 'border-box',
    backgroundColor: color,
    height: `${35}px`,
    width: `${width - 10}px`,
    position: 'absolute',
    display: 'flex',
    left: left + 5,
    top: top,
    margin: '5px 5px 0 0',
    padding: '5px',
    textAlign: 'left',
    overflow: 'hidden',
    textOverflow: 'ellipsis',
    borderRadius: '10px', 
    alignItems: 'center', 
    zIndex: '5',
    '&:hover': {
      cursor: 'pointer',
      boxShadow: 'inset 0 0 100px 100px rgba(255, 255, 255, 0.3)'
    },
  }

  const onClickTaskHandler = (e, task) => {
    e.stopPropagation();
    setCurrentTask((prevState) => {
      return {
        ...task,
        infoForCell: {
          ...task.infoForCell,
          endHour: task.infoForCell.endHour + 1
        }
      }
    });
    handleOpen(e)
  }

  const dragLeaveHandler = (e) => {
    e.target.style.boxShadow = 'none'
  }

  const dragStartHandler = (e, line, task) => {
    setCurrentTask(task);
  }

  const dragEndHandler = (e) => {
    e.target.style.boxShadow = 'none'
  }

  const onClickCopyIconHandler = (e) => {
    e.stopPropagation(); 
    setCopyTask(task)
  }


  return (<>
    <Grid
      draggable={true}
      onDragLeave={(e) => { dragLeaveHandler(e) }}
      onDragStart={(e) => { dragStartHandler(e, line, task) }}
      onDragEnd={(e) => { dragEndHandler(e) }}
      sx={styles}
      onClick={(e) => { onClickTaskHandler(e, task) }}
    >
      <span style={{ maxWidth: '60%', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis' }}>
        {task.title}
      </span>
      <ContentCopyIcon sx={{ width: '20px', cursor: 'pointer', marginLeft: 'auto' }} onClick={(e) => { onClickCopyIconHandler(e) }}>
      </ContentCopyIcon>


    </Grid>
  </>)
};

export default memo(CalendarTask);